@@ -1,7 +1,8 @@
 
-#' Contour ggplot Parameters
+#' Contour ggplot2 Parameters
 #' 
 #' @template args-he
+#' @param pos_legend legend position
 #' @param graph_params Other graphical parameters
 #' @param ... Additional arguments
 #'
@@ -9,13 +10,14 @@
 #' @keywords internal
 #' 
 contour_ggplot_params <- function(he,
+                                  pos_legend,
                                   graph_params,
                                   ...) {
   
   ext_params <- ceplane_geom_params(...)
   
   graph_params$legend <-
-    make_legend_ggplot(he, graph_params$pos_legend)
+    make_legend_ggplot(he, pos_legend)
   
   if (!is.null(graph_params$nlevels)) {
     nlevels <- round(graph_params$nlevels)
@@ -30,7 +32,7 @@ contour_ggplot_params <- function(he,
       quadrant = quadrant_params(he, graph_params),
       size = rel(3.5),
       contour = list(
-        aes_string(colour = "comparison"),
+        aes_string(color = "comparison"),
         contour_var = "ndensity",
         adjust = 2,
         size = 1,
