@@ -1,5 +1,9 @@
 .bcea_env <- new.env(parent = emptyenv())
 
+#' @title .onLoad
+#' @inheritParams base .onLoad
+#' @return invisible
+#' @noRd
 .onLoad <- function(libname, pkgname) {
   op <- options()
   op.bcea <- list(
@@ -7,8 +11,8 @@
   toset <- !(names(op.bcea) %in% names(op))
   if (any(toset)) options(op.bcea[toset])
 
-  ps.options(encoding = "CP1250")
-  pdf.options(encoding = "CP1250")
+  grDevices::ps.options(encoding = "CP1250")
+  grDevices::pdf.options(encoding = "CP1250")
   
   Sys.setenv("_R_CHECK_LENGTH_1_CONDITION_" = "TRUE")
   
