@@ -3,7 +3,8 @@
 # library(purrr)
 
 test_that("ceac.plot_ggplot draws correctly", {
-  load("ce.RData")
+  load(test_path("testdata", "ce.RData"))
+  
   he <- BCEA::bcea(eff, cost)
   
   ceac_plot <- ceac.plot(he, graph = "ggplot2", title = "my title")
